make_reg_matrix: Generate regression matrix for regression based models

Description Usage Arguments Value Examples

View source: R/auxiliar.R

Description

This function takes the metadata from the fit to generate a template of the dependent variables to make forecast.

Usage

1
make_reg_matrix(.fit_output, x_data = NULL, horizon = NULL)

Arguments

.fit_output

Inherited data and meta-data from a model fit.

x_data

Optional DataFrame to use as design matrix.

horizon

Numeric. How far in time to produce a synthetic design matrix.

Value

data-frame or tibble

Examples

1
2
3
4
## Not run: 
make_reg_matrix()

## End(Not run)

opoyc/autoforecast documentation built on May 18, 2021, 1:29 a.m.