Description Usage Arguments Value Examples
This function takes the metadata from the fit to generate a template of the dependent variables to make forecast.
1 | make_reg_matrix(.fit_output, x_data = NULL, horizon = NULL)
|
.fit_output |
Inherited data and meta-data from a model fit. |
x_data |
Optional DataFrame to use as design matrix. |
horizon |
Numeric. How far in time to produce a synthetic design matrix. |
data-frame or tibble
1 2 3 4 | ## Not run:
make_reg_matrix()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.