Description Usage Arguments Value Examples
Time series CV split heuristics should keep temporal dependencies, henceforth, the sample should not be "shuffled" into train and test. This function uses a different strategy to define the test and train sets maintain the order of the data.
1 |
.data |
DataFrame, tibble or tsibble structures. |
test_size |
Numeric. How many periods will be use to asses the forecast accuracy. |
lag |
Numeric. How many periods ahead to start the test size. |
Nested data-frames or tibbles.
1 2 3 4 | ## Not run:
split_ts()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.